===============
Flask-FlatPages
===============

.. image:: https://secure.travis-ci.org/SimonSapin/Flask-FlatPages.png?branch=master
    :target: https://travis-ci.org/SimonSapin/Flask-FlatPages

.. image:: https://pypip.in/v/Flask-FlatPages/badge.png
    :target: https://pypi.python.org/pypi/Flask-FlatPages

Provides flat static pages to a Flask_ application, based on text files
as opposed to a relational database.

* Works on Python 2.6, 2.7 and 3.3+
* BSD licensed
* Latest documentation `on Read the Docs`_
* Source, issues and pull requests `on Github`_
* Releases `on PyPI`_
* Install with ``pip install Flask-FlatPages``

.. _Flask: http://flask.pocoo.org/
.. _on Read the Docs: http://flask-flatpages.readthedocs.org/
.. _on Github: https://github.com/SimonSapin/Flask-FlatPages/
.. _on PyPI: http://pypi.python.org/pypi/Flask-FlatPages
